#include <Imagine/Images.h>
#include "maxflow/graph.h"
#include <iostream>
#include <fstream>

using namespace std;
using namespace Imagine;

// This section shows how to use the library to compute a minimum cut on the following graph:
//
//		        SOURCE
//		       /       \
//		     1/         \6
//		     /      4    \
//		   node0 -----> node1
//		     |   <-----   |
//		     |      3     |
//		     \            /
//		     5\          /1
//		       \        /
//		          SINK
//
///////////////////////////////////////////////////

void testGCuts()
{
	Graph<int,int,int> g(/*estimated # of nodes*/ 2, /*estimated # of edges*/ 1); 
	g.add_node(2); 
	g.add_tweights( 0,   /* capacities */  1, 5 );
	g.add_tweights( 1,   /* capacities */  6, 1 );
	g.add_edge( 0, 1,    /* capacities */  4, 3 );
	int flow = g.maxflow();
	cout << "Flow = " << flow << endl;
	for (int i=0;i<2;i++)
		if (g.what_segment(i) == Graph<int,int,int>::SOURCE)
			cout << i << " is in the SOURCE set" << endl;
		else
			cout << i << " is in the SINK set" << endl;
}

RGB<int> meanCol(const Image<Color>& I) {
	int u,v;
	getMouse(u,v);
	RGB<int> S(0);
	int n=10;
	for (int j=v-n;j<=v+n;j++)
		for (int i=u-n;i<=u+n;i++)
			S=S+RGB<int>(I(i,j));
	RGB<int> M(S/((2*n+1)*(2*n+1)));
	fillRect(u-n,v-n,2*n+1,2*n+1,Color(M));
	return M;
}

void segment(string name,double alpha,double C1,double C2,double C3)
{
	Image<Color> I;
	load(I,stringSrcPath(name));
	int w=I.width(),h=I.height();
	Window W=openWindow(w,h);
	display(I);
	click();
	closeWindow(W);
}

int main() {
	testGCuts();
	segment("fishes.jpg",1.,1.,20.,.0002);
	return 0;
}
